@@ -19,6 +19,10 @@ BACKEND_PBS = 'pbs'
 DEFAULT_BACKEND = BACKEND_LOCAL
 
 
+def get_s3_bucket_name(s3_uri):
+    return s3_uri.replace('s3://', '', 1).split('/')[0]
+
+
 class CromwellBackendCommon(UserDict):
     """Basic stanzas for Cromwell backend conf.
     """
@@ -45,13 +49,22 @@ class CromwellBackendCommon(UserDict):
     }
 
     DEFAULT_MAX_CONCURRENT_WORKFLOWS = 40
+    DEFAULT_MEMORY_RETRY_ERROR_KEYS = ['OutOfMemory', 'Killed']
 
     def __init__(
         self,
         default_backend,
         disable_call_caching=False,
         max_concurrent_workflows=DEFAULT_MAX_CONCURRENT_WORKFLOWS,
+        memory_retry_error_keys=DEFAULT_MEMORY_RETRY_ERROR_KEYS,
     ):
+        """
+        Args:
+            memory_retry_error_keys:
+                List of error strings to catch out-of-memory error
+                See https://cromwell.readthedocs.io/en/develop/cromwell_features/RetryWithMoreMemory
+                for details.
+        """
         super().__init__(deepcopy(CromwellBackendCommon.TEMPLATE))
 
         if default_backend is None:
@@ -59,6 +72,9 @@ class CromwellBackendCommon(UserDict):
         self['backend']['default'] = default_backend
         self['call-caching']['enabled'] = not disable_call_caching
         self['system']['max-concurrent-workflows'] = max_concurrent_workflows
+        # Cromwell's bug in memory-retry feature.
+        # Disabled until it's fixed on Cromwell's side.
+        # self['system']['memory-retry-error-keys'] = memory_retry_error_keys
 
 
 class CromwellBackendServer(UserDict):
@@ -254,15 +270,11 @@ class CromwellBackendGCP(CromwellBackendBase):
     CALL_CACHING_DUP_STRAT_COPY = 'copy'
 
     DEFAULT_GCP_CALL_CACHING_DUP_STRAT = CALL_CACHING_DUP_STRAT_REFERENCE
-    DEFAULT_MEMORY_RETRY_KEYS = ['OutOfMemoryError', 'Killed']
-    DEFAULT_MEMORY_RETRY_MULTIPLIER = 1.2
 
     def __init__(
         self,
         gcp_prj,
         gcp_out_dir,
-        gcp_memory_retry_error_keys=DEFAULT_MEMORY_RETRY_KEYS,
-        gcp_memory_retry_multiplier=DEFAULT_MEMORY_RETRY_MULTIPLIER,
         call_caching_dup_strat=DEFAULT_GCP_CALL_CACHING_DUP_STRAT,
         gcp_service_account_key_json=None,
         use_google_cloud_life_sciences=False,
@@ -283,8 +295,6 @@ class CromwellBackendGCP(CromwellBackendBase):
             gcp_zones:
                 List of zones for Genomics API.
                 Ignored if use_google_cloud_life_sciences.
-            gcp_memory_retry_error_keys:
-                List of error strings to catch out-of-memory error.
         """
         super().__init__(
             backend_name=BACKEND_GCP, max_concurrent_tasks=max_concurrent_tasks
@@ -317,10 +327,6 @@ class CromwellBackendGCP(CromwellBackendBase):
                 {'name': 'application-default', 'scheme': 'application_default'}
             ]
 
-        config['memory-retry'] = {
-            'error-keys': gcp_memory_retry_error_keys,
-            'multiplier': gcp_memory_retry_multiplier,
-        }
         if use_google_cloud_life_sciences:
             self.backend['actor-factory'] = CromwellBackendGCP.ACTOR_FACTORY_V2BETA
             genomics['endpoint-url'] = CromwellBackendGCP.GENOMICS_ENDPOINT_V2BETA
@@ -391,7 +397,9 @@ class CromwellBackendAWS(CromwellBackendBase):
                 'Wrong S3 bucket URI for aws_out_dir: {v}'.format(v=aws_out_dir)
             )
         config['root'] = aws_out_dir
-
+        self.default_runtime_attributes['scriptBucketName'] = get_s3_bucket_name(
+            aws_out_dir
+        )
         self.default_runtime_attributes['queueArn'] = aws_batch_arn
 
 
@@ -404,7 +412,7 @@ class CromwellBackendLocal(CromwellBackendBase):
     TEMPLATE_BACKEND = {
         'actor-factory': 'cromwell.backend.impl.sfs.config.ConfigBackendLifecycleActorFactory',
         'config': {
-            'script-epilogue': 'sleep 10 && sync',
+            'script-epilogue': 'sleep 5',
             'filesystems': {
                 'local': {
                     'localization': ['soft-link', 'hard-link', 'copy'],
@@ -691,7 +699,7 @@ class CromwellBackendPBS(CromwellBackendLocal):
     TEMPLATE_BACKEND = {
         'config': {
             'default-runtime-attributes': {'time': 24},
-            'script-epilogue': 'sleep 30 && sync',
+            'script-epilogue': 'sleep 5',
             'runtime-attributes': dedent(
                 """\
                 String? docker
